.. |4geniac| replace:: 4geniac
.. _4geniac: https://hub.docker.com/u/4geniac


.. |4geniacalmalinux| replace:: 4geniac/almalinux
.. _4geniacalmalinux: https://hub.docker.com/r/4geniac/almalinux/tags

.. |4geniaccentos| replace:: 4geniac/centos
.. _4geniaccentos: https://hub.docker.com/r/4geniac/centos/tags

.. |4geniacrockylinux| replace:: 4geniac/rockylinux
.. _4geniacrockylinux: https://hub.docker.com/r/4geniac/rockylinux/tags

.. |4geniacgithub| replace:: 4geniac on GitHub
.. _4geniacgithub: https://github.com/bioinfo-pf-curie/4geniac

.. |almalinux| replace:: AlmaLinux
.. _almalinux: https://almalinux.org

.. |apptainer| replace:: Apptainer
.. _apptainer: https://apptainer.org/

.. |biogitflow| replace:: biogitflow
.. _biogitflow: https://biogitflow.readthedocs.io

.. |biogitflowref| replace:: biogitflow: development workflow protocols for bioinformatics pipelines with git and GitLab (Kamoun et al., 2020)
.. _biogitflowref: https://f1000research.com/articles/9-632

.. |centos| replace:: CentOS
.. _centos: https://www.centos.org/

.. |cmake| replace:: Cmake
.. _cmake: https://cmake.org/

.. |cmakeexternalproject| replace:: ExternalProject_Add 
.. _cmakeexternalproject: https://cmake.org/cmake/help/latest/module/ExternalProject.html

.. |conda| replace:: Conda
.. _conda: https://docs.conda.io

.. |docker| replace:: Docker
.. _docker: https://www.docker.com/

.. |geniacdemo| replace:: geniac demo
.. _geniacdemo: https://github.com/bioinfo-pf-curie/geniac-demo

.. |geniacdemodsl2| replace:: geniac demo DSL2
.. _geniacdemodsl2: https://github.com/bioinfo-pf-curie/geniac-demo-dsl2

.. |geniacdoc| replace:: geniac documentation
.. _geniacdoc: https://geniac.readthedocs.io/

.. |geniacref| replace:: Geniac: Automatic Configuration GENerator and Installer for nextflow pipelines (Allain et al., 2021)
.. _geniacref: https://open-research-europe.ec.europa.eu/articles/1-76

.. |geniacrepo| replace:: geniac repository
.. _geniacrepo: https://github.com/bioinfo-pf-curie/geniac

.. |geniactemplate| replace:: geniac template
.. _geniactemplate: https://github.com/bioinfo-pf-curie/geniac-template

.. |git| replace:: Git
.. _git: https://git-scm.com/

.. |gitlfs| replace:: Git lfs
.. _gitlfs: https://git-lfs.github.com/

.. |gitsubmodule| replace:: git submodule
.. _gitsubmodule: https://git-scm.com/book/en/v2/Git-Tools-Submodules

.. |make| replace:: Make
.. _make: https://www.gnu.org/software/make/

.. |multiqc| replace:: MultiQC
.. _multiqc: https://multiqc.info

.. |nextflow| replace:: Nextflow
.. _nextflow: https://www.nextflow.io/

.. |nfcore| replace:: nf-core
.. _nfcore: https://nf-co.re/

.. |podman| replace:: Podman
.. _podman: https://podman.io/

.. |rockylinux| replace:: Rocky Linux
.. _rockylinux: https://rockylinux.org

.. |singularity| replace:: Singularity
.. _singularity: https://apptainer.org/

